@@ -49,7 +49,7 @@ def get_fullname(username):
 	for line in p.stdout:
 		m = FULLNAME_PATT.search(line)
 		if m:
-			return m.group(1)
+			return unicode(m.group(1), "latin-1")
 	raise ValueError("Could not find full name for user: %s." % username)
 
 
